@@ -17,19 +17,17 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-
 #include "keyframehelper.h"
 
 #include "kdenlivesettings.h"
 #include "definitions.h"
 
-#include <QDebug>
 #include <QFontDatabase>
 #include <KColorScheme>
 
 #include <QMouseEvent>
-#include <QStylePainter>
 #include <QApplication>
+#include <QPainter>
 
 const int margin = 5;
 
@@ -37,15 +35,15 @@ const int margin = 5;
 
 KeyframeHelper::KeyframeHelper(QWidget *parent) :
     QWidget(parent)
-  , frameLength(1)
-  , m_geom(NULL)
-  , m_position(0)
-  , m_scale(0)
-  , m_movingKeyframe(false)
-  , m_movingItem()
-  , m_hoverKeyframe(-1)
-  , m_seekPosition(SEEK_INACTIVE)
-  , m_offset(0)
+    , frameLength(1)
+    , m_geom(nullptr)
+    , m_position(0)
+    , m_scale(0)
+    , m_movingKeyframe(false)
+    , m_movingItem()
+    , m_hoverKeyframe(-1)
+    , m_seekPosition(SEEK_INACTIVE)
+    , m_offset(0)
 {
     setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     setMouseTracking(true);
@@ -60,7 +58,7 @@ KeyframeHelper::KeyframeHelper(QWidget *parent) :
 }
 
 // virtual
-void KeyframeHelper::mousePressEvent(QMouseEvent * event)
+void KeyframeHelper::mousePressEvent(QMouseEvent *event)
 {
     m_hoverKeyframe = -1;
     if (event->button() != Qt::LeftButton) {
@@ -69,7 +67,7 @@ void KeyframeHelper::mousePressEvent(QMouseEvent * event)
     }
     int xPos = event->x() - margin;
     int headOffset = m_lineHeight / 1.5;
-    if (m_geom != NULL && (event->y() <= headOffset)) {
+    if (m_geom != nullptr && (event->y() <= headOffset)) {
         // check if we want to move a keyframe
         int mousePos = qMax((int)(xPos / m_scale), 0) + m_offset;
         Mlt::GeometryItem item;
@@ -84,7 +82,7 @@ void KeyframeHelper::mousePressEvent(QMouseEvent * event)
 
                 while (!m_extraMovingItems.isEmpty()) {
                     Mlt::GeometryItem *gitem = m_extraMovingItems.takeFirst();
-                    if (gitem) delete gitem;
+                    delete gitem;
                 }
                 for (int i = 0; i < m_extraGeometries.count(); ++i) {
                     if (m_extraGeometries.at(i)->next_key(item, mousePos) == 0) {
@@ -93,7 +91,7 @@ void KeyframeHelper::mousePressEvent(QMouseEvent * event)
                         item2->frame(item.frame());
                         m_extraMovingItems.append(item2);
                     } else {
-                        m_extraMovingItems.append(NULL);
+                        m_extraMovingItems.append(nullptr);
                     }
                 }
                 m_dragStart = event->pos();
@@ -109,7 +107,7 @@ void KeyframeHelper::mousePressEvent(QMouseEvent * event)
     }
 }
 
-void KeyframeHelper::leaveEvent( QEvent * event )
+void KeyframeHelper::leaveEvent(QEvent *event)
 {
     Q_UNUSED(event)
     if (m_hoverKeyframe != -1) {
@@ -119,7 +117,7 @@ void KeyframeHelper::leaveEvent( QEvent * event )
 }
 
 // virtual
-void KeyframeHelper::mouseMoveEvent(QMouseEvent * event)
+void KeyframeHelper::mouseMoveEvent(QMouseEvent *event)
 {
     int xPos = event->x() - margin;
     int headOffset = m_lineHeight / 1.5;
@@ -134,12 +132,14 @@ void KeyframeHelper::mouseMoveEvent(QMouseEvent * event)
             event->accept();
             return;
         }
-        if (m_geom != NULL && (event->y() < m_lineHeight)) {
+        if (m_geom != nullptr && (event->y() < m_lineHeight)) {
             // check if we want to move a keyframe
             Mlt::GeometryItem item;
             if (m_geom->next_key(&item, mousePos) == 0) {
                 if (qAbs((item.frame() - m_offset) * m_scale - xPos) < headOffset) {
-                    if (m_hoverKeyframe == item.frame()) return;
+                    if (m_hoverKeyframe == item.frame()) {
+                        return;
+                    }
                     m_hoverKeyframe = item.frame();
                     setCursor(Qt::PointingHandCursor);
                     update();
@@ -158,25 +158,30 @@ void KeyframeHelper::mouseMoveEvent(QMouseEvent * event)
     }
     if (!m_dragStart.isNull() || m_movingKeyframe) {
         if (!m_movingKeyframe) {
-            if ((QPoint(xPos, event->y()) - m_dragStart).manhattanLength() < QApplication::startDragDistance()) return;
+            if ((QPoint(xPos, event->y()) - m_dragStart).manhattanLength() < QApplication::startDragDistance()) {
+                return;
+            }
             m_movingKeyframe = true;
             m_dragStart = QPoint();
             m_geom->remove(m_movingItem.frame());
-            for (int i = 0; i < m_extraGeometries.count(); ++i)
+            for (int i = 0; i < m_extraGeometries.count(); ++i) {
                 m_extraGeometries[i]->remove(m_movingItem.frame());
+            }
         }
         int pos = qBound(0, (int)(xPos / m_scale), frameLength);
-        if (KdenliveSettings::snaptopoints() && qAbs(pos - m_position) < headOffset / m_scale)
+        if (KdenliveSettings::snaptopoints() && qAbs(pos - m_position) < headOffset / m_scale) {
             pos = m_position;
+        }
         m_movingItem.frame(pos + m_offset);
         for (int i = 0; i < m_extraMovingItems.count(); ++i) {
-            if (m_extraMovingItems.at(i))
+            if (m_extraMovingItems.at(i)) {
                 m_extraMovingItems[i]->frame(pos);
+            }
         }
         update();
         return;
     }
-    m_seekPosition = (int) (xPos / m_scale);
+    m_seekPosition = (int)(xPos / m_scale);
     m_seekPosition = qMax(0, m_seekPosition);
     m_seekPosition = qMin(frameLength, m_seekPosition);
     m_hoverKeyframe = -2;
@@ -184,9 +189,9 @@ void KeyframeHelper::mouseMoveEvent(QMouseEvent * event)
     update();
 }
 
-void KeyframeHelper::mouseDoubleClickEvent(QMouseEvent * event)
+void KeyframeHelper::mouseDoubleClickEvent(QMouseEvent *event)
 {
-    if (m_geom != NULL && event->button() == Qt::LeftButton) {
+    if (m_geom != nullptr && event->button() == Qt::LeftButton) {
         // check if we want to move a keyframe
         int xPos = event->x() - margin;
         int mousePos = qMax((int)(xPos / m_scale - 5), 0) + m_offset;
@@ -202,7 +207,7 @@ void KeyframeHelper::mouseDoubleClickEvent(QMouseEvent * event)
 }
 
 // virtual
-void KeyframeHelper::mouseReleaseEvent(QMouseEvent * event)
+void KeyframeHelper::mouseReleaseEvent(QMouseEvent *event)
 {
     setCursor(Qt::ArrowCursor);
     m_hoverKeyframe = -1;
@@ -211,14 +216,14 @@ void KeyframeHelper::mouseReleaseEvent(QMouseEvent * event)
         m_movingKeyframe = false;
 
         for (int i = 0; i < m_extraGeometries.count(); ++i) {
-            if (m_extraMovingItems.at(i))
+            if (m_extraMovingItems.at(i)) {
                 m_extraGeometries[i]->insert(m_extraMovingItems.at(i));
+            }
         }
         m_movingKeyframe = false;
         emit keyframeMoved(m_position);
         return;
-    }
-    else if (!m_dragStart.isNull()) {
+    } else if (!m_dragStart.isNull()) {
         m_seekPosition = m_movingItem.frame();
         m_dragStart = QPoint();
         emit requestSeek(m_seekPosition);
@@ -227,12 +232,13 @@ void KeyframeHelper::mouseReleaseEvent(QMouseEvent * event)
 }
 
 // virtual
-void KeyframeHelper::wheelEvent(QWheelEvent * e)
+void KeyframeHelper::wheelEvent(QWheelEvent *e)
 {
-    if (e->delta() < 0)
+    if (e->delta() < 0) {
         --m_position;
-    else
+    } else {
         ++m_position;
+    }
     m_position = qMax(0, m_position);
     m_position = qMin(frameLength, m_position);
     emit requestSeek(m_position);
@@ -251,13 +257,15 @@ void KeyframeHelper::paintEvent(QPaintEvent *e)
     p.setRenderHints(QPainter::Antialiasing);
     const QRectF clipRect = e->rect();
     p.setClipRect(clipRect);
-    m_scale = (double) (width() - 2 * margin) / frameLength;
+    m_scale = (double)(width() - 2 * margin) / frameLength;
     int headOffset = m_lineHeight / 1.5;
-    if (m_geom != NULL) {
+    if (m_geom != nullptr) {
         int pos = m_offset;
         Mlt::GeometryItem item;
         while (true) {
-            if (m_geom->next_key(&item, pos) == 1) break;
+            if (m_geom->next_key(&item, pos) == 1) {
+                break;
+            }
             pos = item.frame();
             int offsetPos = pos - m_offset;
             if (offsetPos < 0) {
@@ -270,8 +278,7 @@ void KeyframeHelper::paintEvent(QPaintEvent *e)
                 // active keyframe
                 p.setBrush(m_selected);
                 p.setPen(m_selected);
-            }
-            else {
+            } else {
                 p.setPen(palette().text().color());
                 p.setBrush(palette().text());
             }
@@ -301,10 +308,11 @@ void KeyframeHelper::paintEvent(QPaintEvent *e)
     const int cursor = margin + m_position * m_scale;
     int cursorwidth = (m_size - (m_lineHeight + headOffset / 2)) / 2 + 1;
     pa.setPoints(3, cursor - cursorwidth, m_size, cursor + cursorwidth, m_size, cursor, m_lineHeight + (headOffset / 2) + 1);
-    if (m_hoverKeyframe == -2)
+    if (m_hoverKeyframe == -2) {
         p.setBrush(palette().highlight());
-    else
+    } else {
         p.setBrush(palette().text());
+    }
     p.drawPolygon(pa);
 }
 
@@ -318,8 +326,9 @@ int KeyframeHelper::value() const
 
 void KeyframeHelper::setValue(const int pos)
 {
-    if (pos == m_position || m_geom == NULL)
+    if (pos == m_position || m_geom == nullptr) {
         return;
+    }
     if (pos == m_seekPosition) {
         m_seekPosition = SEEK_INACTIVE;
     }
@@ -340,4 +349,3 @@ void KeyframeHelper::addGeometry(Mlt::Geometry *geom)
     m_extraGeometries.append(geom);
 }
 
-
