@@ -20,7 +20,7 @@ the Free Software Foundation, either version 3 of the License, or
 #include <KSharedConfig>
 #include <klocalizedstring.h>
 
-LayoutManagement::LayoutManagement(QObject* parent) :
+LayoutManagement::LayoutManagement(QObject *parent) :
     QObject(parent)
 {
     // Prepare layout actions
@@ -37,15 +37,17 @@ LayoutManagement::LayoutManagement(QObject* parent) :
     }
     // Required to enable user to add the load layout action to toolbar
     layoutActions->addAction(QStringLiteral("load_layouts"), m_loadLayout);
-    connect(m_loadLayout, SIGNAL(triggered(QAction*)), SLOT(slotLoadLayout(QAction*)));
+    connect(m_loadLayout, SIGNAL(triggered(QAction *)), SLOT(slotLoadLayout(QAction *)));
 
-    connect(pCore->window(), SIGNAL(GUISetupDone()), SLOT(slotOnGUISetupDone()));
+    connect(pCore->window(), &MainWindow::GUISetupDone, this, &LayoutManagement::slotOnGUISetupDone);
 }
 
 void LayoutManagement::initializeLayouts()
 {
-    QMenu *saveLayout = static_cast<QMenu*>(pCore->window()->factory()->container(QStringLiteral("layout_save_as"), pCore->window()));
-    if (m_loadLayout == NULL || saveLayout == NULL) return;
+    QMenu *saveLayout = static_cast<QMenu *>(pCore->window()->factory()->container(QStringLiteral("layout_save_as"), pCore->window()));
+    if (m_loadLayout == nullptr || saveLayout == nullptr) {
+        return;
+    }
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup layoutGroup(config, "Layouts");
     QStringList entries = layoutGroup.keyList();
@@ -53,10 +55,10 @@ void LayoutManagement::initializeLayouts()
     QList<QAction *> saveActions = saveLayout->actions();
     for (int i = 1; i < 5; ++i) {
         // Rename the layouts actions
-        foreach(const QString & key, entries) {
+        foreach (const QString &key, entries) {
             if (key.endsWith(QStringLiteral("_%1").arg(i))) {
                 // Found previously saved layout
-                QString layoutName = key.section('_', 0, -2);
+                QString layoutName = key.section(QLatin1Char('_'), 0, -2);
                 for (int j = 0; j < loadActions.count(); ++j) {
                     if (loadActions.at(j)->data().toString().endsWith('_' + QString::number(i))) {
                         loadActions[j]->setText(layoutName);
@@ -96,10 +98,10 @@ void LayoutManagement::slotLoadLayout(QAction *action)
 void LayoutManagement::slotSaveLayout(QAction *action)
 {
     QString originallayoutName = action->data().toString();
-    int layoutId = originallayoutName.section('_', -1).toInt();
+    int layoutId = originallayoutName.section(QLatin1Char('_'), -1).toInt();
 
     QString layoutName = QInputDialog::getText(pCore->window(), i18n("Save Layout"), i18n("Layout name:"), QLineEdit::Normal,
-                                               originallayoutName.section('_', 0, -2));
+                         originallayoutName.section(QLatin1Char('_'), 0, -2));
     if (layoutName.isEmpty()) {
         return;
     }
@@ -115,12 +117,11 @@ void LayoutManagement::slotSaveLayout(QAction *action)
 
 void LayoutManagement::slotOnGUISetupDone()
 {
-    QMenu *saveLayout = static_cast<QMenu*>(pCore->window()->factory()->container(QStringLiteral("layout_save_as"), pCore->window()));
+    QMenu *saveLayout = static_cast<QMenu *>(pCore->window()->factory()->container(QStringLiteral("layout_save_as"), pCore->window()));
     if (saveLayout) {
-        connect(saveLayout, SIGNAL(triggered(QAction*)), SLOT(slotSaveLayout(QAction*)));
+        connect(saveLayout, &QMenu::triggered, this, &LayoutManagement::slotSaveLayout);
     }
 
     initializeLayouts();
 }
 
-
